from setuptools import setup


setup(name='nexmo',
  version='1.0.1',
  description='A Python wrapper for the Nexmo API',
  long_description='A Python wrapper for the Nexmo API',
  url='http://github.com/timcraft/python-nexmo',
  author='Tim Craft',
  author_email='mail@timcraft.com',
  license='LGPL-3.0',
  packages=['nexmo'],
  platforms=['any'],
  install_requires=['requests'])
